Hvað er OiRA | OiRA

Þemu

# Hvað er OiRA

## Aldrei notað OiRA?

Hér er stutt kynning á áhættumatinu og hvernig OiRA getur hjálpað þér við það.

## Hvað er áhættumat?

Áhættumat er grundvöllurinn að árangursríkri öryggis- og heilbrigðisstjórnun og lykillinn að því að draga úr vinnutengdum slysum og sjúkdómum. Ef það er framkvæmt með réttum hætti getur það bætt öryggi og heilbrigði á vinnustöðum og rekstrarlega frammistöðu fyrirtækisins almennt.

Öryggi og heilbrigði launþega er verndað í Evrópu með mati og stjórnun á áhættu á vinnustöðum. Vinnuveitendum ber lagaleg skylda til að tryggja öryggi og heilbrigði launþega að öllu leyti sem tengist vinnu þeirra og framkvæma áhættumat. Öll fyrirtæki verða því að framkvæma áhættumat og búa til aðgerðaáætlun. Til að framkvæma árangursríkt áhættumat á vinnustaðnum þurfa allir hlutaðeigendur að átta sig vel á:

- lagalegu samhengi og hugtökum;
- ferlinu við að leggja mat á áhættu;
- hlutverki helstu aðila sem taka þátt í ferlinu.

Launþegar og/eða fulltrúar þeirra eiga rétt á því að vera með í ráðum um fyrirkomulag framkvæmdarinnar og taka þátt í áhættumatinu.

Finna má frekari upplýsingar um áhættumat og þátttöku launþega og fulltrúa þeirra í áhættumatsferlinu á vefsíðu OiRA-verkefnisins.

## Hvað er OiRA?

OiRA stendur fyrir rafrænt gagnvirkt áhættumat (e. Online Interactive Risk Assessment). Um er að ræða vefhugbúnað sem gerir þér kleift að framkvæma áhættumat á öryggi og heilbrigði vinnustaðarins þíns.

## Fyrir hvern er OiRA?

Allir geta notað OiRA til að leggja mat á hugsanlega öryggis- og heilbrigðisáhættu á vinnustað þeirra.

En OiRA er hannað til að gagnast mest litlum vinnustöðum. OiRA var sérstaklega þróað til að hjálpa þeim við að leggja mat á áhættu á vinnustaðnum og búa til skrásett áhættumat, þar á meðal aðgerðaáætlun sem er sérsniðin að þörfum viðkomandi fyrirtækis.

## Hvað þarf ég að gera?

Ljúka þarf fjölmörgum skrefum í OiRA áhættumatsferlinu:

- Undirbúningur: sem verkfæri innihalda spurningar sem hjálpa þér að sérsníða verkfærið að séreinkennum fyrirtækisins þíns. Þegar þú svarar spurningunum mun verkfærið laga sig að séreinkennum þínum og birta þær einingar sem eiga við.

- Þátttaka: framkvæma ætti öll áhættumöt með virkri þátttöku starfsmanna. Verkfærið býður þér upp á að prenta út heildartexta áhættumatsins eða hluta þess svo þú getir haft starfsmenn með í ráðum og fengið álit þeirra.

- Áhættugreining: OiRA mun sýna hugsanlegar hættur eða vandamál fyrir öryggi og heilbrigði sem kunna að vera til staðar á vinnustaðnum þínum. Með því að svara fullyrðingunum/spurningunum annaðhvort með já eða nei greinir þú frá því hvort slíkar hættur eða vandamál séu til staðar. Þú getur einnig tekið ákvörðun um að skilja spurningu eftir ósvaraðri og geyma hana til að svara síðar.

- Mat: sum verkfæri biðja þig um að forgangsraða áhættu sem þú hefur borið kennsl á. Það má gera með mismunandi hætti og fer það eftir þeim ákvörðunum sem innlendar OiRA landsskrifstofur/hugbúnaðarhönnuðir hafa tekið og nálgun þeirra. Sum verkfæri forgangsraða áhættu sjálfkrafa í bakgrunninum og þú getur svo gert breytingar á henni.

- Aðgerðaáætlun: verkfærið biður þig um að taka ákvörðun um eina eða fleiri ráðstafanir fyrir alla auðkennda áhættu til að útrýma eða draga úr henni. Flest verkfæri innihalda uppástungur um ráðstafanir fyrir þig. Þú getur alltaf valið að færa inn eigin ráðstafanir.

- Skýrsla: þér ber lagaleg skylda til að skrásetja áhættumatið. Í skýrsluhlutanum finnur þú fjölbreyttar skýrslur sem hjálpa þér að fylgjast með áhættumatinu og fylgja því á eftir með aðgerðum/ráðstöfunum sem þú hefur ákveðið að innleiða til að útrýma eða draga úr auðkenndri áhættu.

## Hversu langan tíma tekur það?

Það er ómögulegt að segja hversu langan tíma áhættumatið mun almennt taka þar sem verkfærin eru mismunandi á milli atvinnugreina og landa.

En þú getur varið þeim tíma, sem þú hefur, í matið og komið svo aftur við fyrsta tækifæri og haldið áfram þar sem frá var horfið.

## Af hverju þarf ég að skrá mig?

Það fyrsta, sem þú verður beðin/n um þegar þú byrjar fyrsta áhættumatið þitt, er að búa til OiRA aðgang - en það er einfalt og fljótlegt.

Skráningin gerir þér kleift að skrá þig einfaldlega inn hvenær sem er til að halda áfram með fyrri möt eða byrja ný.

Ef þú ert skráður notandi gefst þér einnig tækifæri til að búa til útprentuð, nákvæm og dagrétt áhættumöt hvenær sem er.

## Þarf ég að undirbúa mig?

Þú þarft engan sérstakan undirbúning til að byrja að nota verkfærið en þú ættir að taka þér smá tíma í að velta fyrir þér hver muni framkvæma áhættumatið og hvernig starfsmenn munu koma að ferlinu.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More